#!/usr/bin/tcl

# script which runs the whole simulation for different values

# |---------COLUMNS--------|

# --x--x--x--x--x--x--x--x--   --
# --x--x--x--x--x--x--x--x--  
# --x--x--x--x--x--x--x--x--  ROWS
# --x--x--x--x--x--x--x--x--   
# --x--x--x--x--x--x--x--x--   --

# name of the file where hspice puts the results
set results "hspicetest.mt0"
set resultstr "hspicetest.tr0"
set resultfilename "results.txt"
set tmpfilename "tmpfile.txt"
set parsedresultsfilename "parsedresults.txt"


# variable declaration
set ROWS ""
set COLUMNS ""
set CSW ""
set CDEC ""
set REQ ""
set MOD ""

# source config file, where all the variables are assigned
source spiceconfig.tcl

exec rm -f $resultfilename

# loop over all modules
set modcount 0
foreach module ${MOD} {

	set discharge_file_name "${module}_discharge_times.dat"
	set charge_file_name "${module}_charge_times.dat"
	set min_voltage_file_name "${module}_min_voltages.dat"
	set peak_current_file_name "${module}_peak_currents.dat"
	set power_on_energy_file_name "${module}_power_on_energy.dat"
	set power_off_energy_file_name "${module}_power_off_energy.dat"
	

	
	exec rm -f $discharge_file_name
	exec rm -f $charge_file_name
	exec rm -f $min_voltage_file_name
	exec rm -f $peak_current_file_name
	exec rm -f $power_on_energy_file_name
	exec rm -f $power_off_energy_file_name

	# loop over all switch configurations
	for { set rowcount 0} { ${rowcount} < ${NUM_ROWS}} {incr rowcount} {		
		
		# set current rows and colums
		set row [lindex ${ROWS} ${rowcount}]
		set column [lindex ${COLUMNS} ${rowcount}]
		
		# set current capacitance and resistance
		set CSW_CUR [lindex ${CSW} ${modcount}]
		set CDEC_CUR [lindex ${CDEC} ${modcount}]
		set REQ_CUR [lindex ${REQ} ${modcount}]
		
		# print to stdout
		puts "\n$module"
		puts "row: $row"
		puts "column: $column"
		puts "cswich: $CSW_CUR"
		puts "cdecap: $CDEC_CUR"
		puts "req: $REQ_CUR"
		
		set resfilename "${module}_${row}x${column}.res" 	
		set results_tran_filename "${module}_${row}x${column}_tran.tr0"
		exec rm -f $resfilename

		# generate switch chain and circuit
		source make_switch_chain.tcl
		source make_circuit.tcl
		
		# run the simulation
		puts "starting the simulation"		
		set rc [catch { exec hspice hspicetest.sp } msg ]
		
		# copy result to another file and add information
		# about current module and values
		#file copy -force ${results} ${resfilename}
		set tmpfile [open ${tmpfilename} w]
		puts $tmpfile "--------------------------------------------------------------------------------\n"
		puts $tmpfile "\nmodule: $module"
		puts $tmpfile "rows: $row"
		puts $tmpfile "columns: $column"
		puts $tmpfile "switching cap: $CSW_CUR"
		puts $tmpfile "decap: $CDEC_CUR"
		puts $tmpfile "equ. resistance: $REQ_CUR\n"
		close ${tmpfile}
		
		source testlineparse.tcl
		
		exec cat ${tmpfilename} ${parsedresultsfilename} > $resfilename
		
		exec cat $tmpfilename >> $resultfilename
		exec cat ${parsedresultsfilename} >> $resultfilename
		file copy -force ${resultstr} ${results_tran_filename}
		
	}
	incr modcount
}

set resultfile [open $resultfilename a]
puts $resultfile "--------------------------------------------------------------------------------\n"
close $resultfile


