#!/usr/bin/tcl

proc SplitIntoWords {block} {

    # We need to split the block up into words but cannot use
    # list operations as they throw away some significant
    # quoting, and [split] ignores braces as it should.
    # Therefore what we do is gradually build up a string out of
    # whitespace seperated strings. We cannot use [split] to
    # split the block into whitespace seperated strings as it
    # throws away the whitespace which maybe important so we
    # have to do it all by hand.

    set words {}
    set word ""

    while {[string length $block]} {
        # Look for the next group of whitespace characters.
        if {[regexp -indices "\[ \t\n\]+" $block all]} {
	    # Remove the text leading up to and including the white space
	    # from the block.
	    set text [string range $block 0 [lindex $all 1]]
	    set block [string range $block [expr {[lindex $all 1] + 1}] end]
	} else {
	    # Take everything up to the end of the block.
	    set text $block
	    set block {}
	}

	# Add the text to the end of the word we are building up.
        append word $text

        if { [catch {llength $word} length] == 0 && $length == 1} {
	    # The word is a valid list so add it to the list.
	    lappend words [string trim $word]
	    set word {}
        }
    }

    # If the last word has not been added to the list then there
    # is a problem.
    if { [string length $word] } {
	error "incomplete word \"$word\""
    }

    return $words
 }


set test_app "dwt"



set fu_vec2_filename "fu_vec2.dat"
set fu_uwb_cor_filename "fu_uwb_cor.dat"
set fu_vector_ag_filename "fu_vector_ag.dat"
set is2_filename "is2.dat"
set fu_vec_filename "fu_vec.dat"

#set test_state {acq_noise acq_coarse acq_del_comp_coarse acq_fine acq_sfd acq_psdu}
set test_state {main}
#set test_state {complete}
set test_unit {fu_is1_mul}

#lappend test_state "acq_noise"
#lappend test_state "acq_coarse"
#lappend test_state "acq_del_comp_coarse"
#lappend test_state "acq_fine"
#lappend test_state "acq_sfd"
#lappend test_state "acq_psdu"

#lappend test_unit "fu_is1_mul"
#lappend test_unit "is2"
#lappend test_unit "fu_vec"
#lappend test_unit "fu_vec2"
#lappend test_unit "vis"


foreach curr_state ${test_state} {
	foreach curr_test_unit ${test_unit} {

		set registerlog_filename "${test_app}_${curr_state}_register.log"
		set unit_result_filename "${test_app}_${curr_state}_${curr_test_unit}.dat"
		set results_filename "${test_app}_${curr_state}_${curr_test_unit}_over_time.txt"
		set units_filename "${test_app}_units_${curr_test_unit}.txt"

		source extract_units.tcl

		set registerlog [open $registerlog_filename r]
		set units_file [open $units_filename r]
		set results_file [open $results_filename w]
		set units_results_file [open $unit_result_filename w]

		set units [split [read $units_file] \n]

		set linecount 0

		foreach line [split [read $registerlog] \n] {

			set words [SplitIntoWords $line]
			if { [string is integer [lindex $words 0]] == 1 && [string length [lindex $words 0]] > 0} {
				set curr_PC [lindex [split [lindex $words 1] ()] 1]
				puts $results_file "PC: ${curr_PC}, cycle: [lindex $words 0] => [lindex $units ${curr_PC}]"
				set curr_line [SplitIntoWords [lindex $units ${curr_PC}]]
				if {[string length [lindex $units ${curr_PC}]] > 0} {
					puts -nonewline $units_results_file "1 "
				} else {
					puts -nonewline $units_results_file "0 "
				}		
			}
			incr linecount
		}


		close $registerlog
		close $units_file
		close $results_file
		close $units_results_file
		
	}	
}

