#!/usr/bin/tcl

proc SplitIntoWords {block} {

    # We need to split the block up into words but cannot use
    # list operations as they throw away some significant
    # quoting, and [split] ignores braces as it should.
    # Therefore what we do is gradually build up a string out of
    # whitespace seperated strings. We cannot use [split] to
    # split the block into whitespace seperated strings as it
    # throws away the whitespace which maybe important so we
    # have to do it all by hand.

    set words {}
    set word ""

    while {[string length $block]} {
        # Look for the next group of whitespace characters.
        if {[regexp -indices "\[ \t\n\]+" $block all]} {
	    # Remove the text leading up to and including the white space
	    # from the block.
	    set text [string range $block 0 [lindex $all 1]]
	    set block [string range $block [expr {[lindex $all 1] + 1}] end]
	} else {
	    # Take everything up to the end of the block.
	    set text $block
	    set block {}
	}

	# Add the text to the end of the word we are building up.
        append word $text

        if { [catch {llength $word} length] == 0 && $length == 1} {
	    # The word is a valid list so add it to the list.
	    lappend words [string trim $word]
	    set word {}
        }
    }

    # If the last word has not been added to the list then there
    # is a problem.
    if { [string length $word] } {
	error "incomplete word \"$word\""
    }

    return $words
 }


global curr_test_unit
global test_app

set usage_filename "${test_app}_units_${curr_test_unit}.as"
set units_filename "${test_app}_units_${curr_test_unit}.txt"

set usage_file [open $usage_filename r]
set units_file [open $units_filename w]

set linecount 0

foreach line [split [read $usage_file] \n] {

	set parse_units 0
		
		if { [string is integer [lindex $line 0]] } {
			if { [string match 0x* [lindex $line 0]] == 0 && [string length [lindex $line 0]] > 0} {				
				
				# split line into words
				set words [SplitIntoWords $line] 
				
				# find index of @
				for {set curr_index 0} {${curr_index} < [llength ${words}]} {incr curr_index} {
					if {[string match @ [lindex $words $curr_index]] == 1} {
						
						# set flag to write units into file and break
						set parse_units 1
						break
					}
				}
				# write units to file	
				if {$parse_units == 1} {
					for {set parse_index [expr $curr_index +1]} {${parse_index} < [llength ${words}]} {incr parse_index} {
						puts -nonewline ${units_file} "[lindex $words $parse_index] "
					}
				}
				puts ${units_file} ""
			}
		}

	incr linecount
	
}


close $usage_file
close $units_file
